@@ -70,10 +70,21 @@ class ecLibDb extends BaseDb
 	 */
 	function getTaxRate($rateTypeId, $dt = null)
 	{
+		$initDt = $this->gEnv->getInitValueOfTimestamp();		// 日時初期化値
+		if (is_null($dt)) $dt = date("Y/m/d H:i:s");	// 現在日時
+		
+		// 税率はtr_indexが最大のレコードを取得
+		$params = array();
 		$queryStr  = 'SELECT * FROM tax_rate ';
-		$queryStr .=   'WHERE tr_id = ? ';
+		$queryStr .= 'WHERE tr_id = ? '; $params[] = $rateTypeId;
+		
+		$queryStr .=   'AND (tr_active_start_dt = ? OR (tr_active_start_dt != ? AND tr_active_start_dt <= ?)) ';
+		$params[] = $initDt;
+		$params[] = $initDt;
+		$params[] = $dt;
+		
 		$queryStr .=   'ORDER BY tr_index DESC';
-		$ret = $this->selectRecord($queryStr, array($rateTypeId), $row);
+		$ret = $this->selectRecord($queryStr, $params, $row);
 		if ($ret){
 			return $row['tr_rate'];
 		} else {
@@ -586,6 +597,62 @@ class ecLibDb extends BaseDb
 		if ($ret) $status = $row['oe_status'];
 		return $status;
 	}
+	/**
+	 * 実行可能な配送方法を取得
+	 *
+	 * @param string $langId		言語
+	 * @param int    $setId			セットID
+	 * @param array  $rows			取得レコード
+	 * @return bool					1行以上取得 = true, 取得なし= false
+	 */
+	function getActiveDelivMethodRows($langId, $setId, &$rows)
+	{
+		$queryStr  = 'SELECT * FROM delivery_method_def LEFT JOIN _iwidgets ON do_iwidget_id = iw_id AND iw_deleted = false ';
+		$queryStr .= 'WHERE do_deleted = false ';
+		$queryStr .=   'AND do_visible = true ';			// 表示状態
+		$queryStr .=   'AND do_language_id = ? ';
+		$queryStr .=   'AND do_set_id = ? ';
+		$queryStr .= 'ORDER BY do_index ';
+		$retValue = $this->selectRecords($queryStr, array($langId, $setId), $rows);
+		return $retValue;
+	}
+	/**
+	 * 実行可能な配送方法を取得
+	 *
+	 * @param string	$langId				言語
+	 * @param int		$setId				セットID
+	 * @param function	$callback			コールバック関数
+	 * @return 			なし
+	 */
+/*	function getActiveDelivMethod($langId, $setId, $callback)
+	{
+		$queryStr = 'SELECT * FROM delivery_method_def ';
+		$queryStr .=  'WHERE do_deleted = false ';
+		$queryStr .=  'AND do_visible = true ';			// 表示状態
+		$queryStr .=  'AND do_language_id = ? ';
+		$queryStr .=  'AND do_set_id = ? ';
+		$queryStr .=  'ORDER BY do_index ';
+		$this->selectLoop($queryStr, array($langId, $setId), $callback);
+	}*/
+	/**
+	 * 実行可能な支払方法を取得
+	 *
+	 * @param string $langId		言語
+	 * @param int    $setId			セットID
+	 * @param array  $rows			取得レコード
+	 * @return bool					1行以上取得 = true, 取得なし= false
+	 */
+	function getActivePayMethodRows($langId, $setId, &$rows)
+	{
+		$queryStr  = 'SELECT * FROM pay_method_def LEFT JOIN _iwidgets ON po_iwidget_id = iw_id AND iw_deleted = false ';
+		$queryStr .= 'WHERE po_deleted = false ';
+		$queryStr .=   'AND po_visible = true ';			// 表示状態
+		$queryStr .=   'AND po_language_id = ? ';
+		$queryStr .=   'AND po_set_id = ? ';
+		$queryStr .= 'ORDER BY po_index ';
+		$retValue = $this->selectRecords($queryStr, array($langId, $setId), $rows);
+		return $retValue;
+	}
 	/**
 	 * 商品情報を取得
 	 *
