@@ -909,7 +909,11 @@ class linkInfo
 			if (!isset($orderNo)) $orderNo = 100;
 			$sortParam[] = array('key' => $key, 'value' => $value, 'no' => $orderNo);
 		}
-		usort($sortParam, create_function('$a,$b', 'return $a["no"] - $b["no"];'));
+//		usort($sortParam, create_function('$a,$b', 'return $a["no"] - $b["no"];'));
+		usort($sortParam, function($a, $b)
+		{
+			return $a['no'] - $b['no'];
+		});
 		
 		// 文字列を作成
 		$sortCount = count($sortParam);
