@@ -38,6 +38,7 @@ class ScriptLibInfo
 //	const SELECTED_LIB_ELFINDER = 'elfinder115';		// 選択中のelFinder、「elfinder」または「elfinder112」「elfinder115」「elfinder123」が設定可能。(PHP v5.3対応) 
 //	const SELECTED_LIB_ELFINDER = 'elfinder123';		// 選択中のelFinder、「elfinder」または「elfinder112」「elfinder115」「elfinder123」が設定可能。(PHP v5.3対応) 
 	const SELECTED_LIB_ELFINDER = 'elfinder130';		// 選択中のelFinder、「elfinder」または「elfinder112」「elfinder115」「elfinder123」「elfinder130」が設定可能。(PHP v5.3対応) 
+//	const SELECTED_LIB_ELFINDER = 'elfinder139';		// 選択中のelFinder、「elfinder」または「elfinder112」「elfinder115」「elfinder123」「elfinder130」「elfinder139」が設定可能。
 		
 	// ##### Javascriptライブラリ(DBでの設定値) #####
 	// ライブラリセット(複数ライブラリの構成)
@@ -55,6 +56,7 @@ class ScriptLibInfo
 //	const LIB_ELFINDER121			= 'elfinder121';			// v2.1.21
 	const LIB_ELFINDER123			= 'elfinder123';			// v2.1.23
 	const LIB_ELFINDER130			= 'elfinder130';			// v2.1.30
+	const LIB_ELFINDER139			= 'elfinder139';			// v2.1.39
 	const LIB_MD5					= 'md5';
 	const LIB_MOMENT				= 'moment';
 	const LIB_SWFOBJECT				= 'swfobject';
@@ -375,6 +377,14 @@ const JQUERY_TABLEDND_FILENAME		= 'jquery/tablednd/jquery.tablednd-0.9.2.js';
 //	const ELFINDER130_CSS			= 'elfinder-2.1.30/css/elfinder.min.css';		// elFinder CSS
 	const ELFINDER130_OPTION_CSS	= 'elfinder-2.1.30/css/theme.css';				// elFinder CSS
 
+	const ELFINDER139_VER			= '2.1.39';									// elFinderバージョン
+//	const ELFINDER139_FILENAME		= 'elfinder-2.1.39/js/elfinder.full.js';		// elFinder
+	const ELFINDER139_FILENAME		= 'elfinder-2.1.39/js/elfinder.min.js';		// elFinder
+	const ELFINDER139_LANG_FILENAME	= 'elfinder-2.1.39/js/i18n/elfinder.ja.js';	// elFinder言語ファイル
+	const ELFINDER139_CSS			= 'elfinder-2.1.39/css/elfinder.full.css';		// elFinder CSS
+//	const ELFINDER139_CSS			= 'elfinder-2.1.39/css/elfinder.min.css';		// elFinder CSS
+	const ELFINDER139_OPTION_CSS	= 'elfinder-2.1.39/css/theme.css';				// elFinder CSS
+	
 	const MD5_FILENAME				= 'md5.js';									// MD5
 	const SOCKETIO_FILENAME			= 'socket.io/socket.io.js';					// socket.io
 	const MOMENT_FILENAME			= 'moment-with-locales-2.9.0.js';			// Moment.js
@@ -728,6 +738,11 @@ const JQUERY_TABLEDND_FILENAME		= 'jquery/tablednd/jquery.tablednd-0.9.2.js';
 															'css'		=> array(self::ELFINDER130_CSS, self::ELFINDER130_OPTION_CSS),	// テーマは最初に読み込む
 															'version'	=> self::ELFINDER130_VER					// elFinderバージョン
 														);
+			} else if (self::SELECTED_LIB_ELFINDER == self::LIB_ELFINDER139){
+				self::$libs[self::LIB_ELFINDER] = array(	'script' 	=> array(self::ELFINDER139_FILENAME, self::ELFINDER139_LANG_FILENAME),		// elFinder v2.1.39
+															'css'		=> array(self::ELFINDER139_CSS, self::ELFINDER139_OPTION_CSS),	// テーマは最初に読み込む
+															'version'	=> self::ELFINDER139_VER					// elFinderバージョン
+														);
 			}
 
 			// WYSIWYGエディターに合わせてライブラリを設定
@@ -805,7 +820,7 @@ const JQUERY_TABLEDND_FILENAME		= 'jquery/tablednd/jquery.tablednd-0.9.2.js';
 	{
 		// ##### 依存ライブラリ情報 #####
 		static $dependentLib = array(
-										self::LIB_ELFINDER						=> array(self::LIB_BOOTSTRAP, self::LIB_JQUERY_UI, self::LIB_JQUERY_UI_WIDGETS_DIALOG, self::LIB_JQUERY_UI_WIDGETS_SLIDER),	// 画像リサイズが実行できないバグの対応。jQuery UIよりも前にBootstrapを読ませる必要がある。(2015/1/25)
+										self::LIB_ELFINDER						=> array(self::LIB_JQUERY_UI, self::LIB_JQUERY_UI_WIDGETS_DIALOG, self::LIB_JQUERY_UI_WIDGETS_SLIDER),	// 最新ではBootstrapを先に読ませない。elFinder v2.1.30以降で問題がなくなった?(2018/6/25)
 										self::LIB_ELFINDER112					=> array(self::LIB_BOOTSTRAP, self::LIB_JQUERY_UI, self::LIB_JQUERY_UI_WIDGETS_DIALOG, self::LIB_JQUERY_UI_WIDGETS_SLIDER),	// 画像リサイズが実行できないバグの対応。jQuery UIよりも前にBootstrapを読ませる必要がある。(2015/1/25)
 										self::LIB_ELFINDER115					=> array(self::LIB_BOOTSTRAP, self::LIB_JQUERY_UI, self::LIB_JQUERY_UI_WIDGETS_DIALOG, self::LIB_JQUERY_UI_WIDGETS_SLIDER),	// 画像リサイズが実行できないバグの対応。jQuery UIよりも前にBootstrapを読ませる必要がある。(2015/1/25)
 //										self::LIB_ELFINDER121					=> array(self::LIB_BOOTSTRAP, self::LIB_JQUERY_UI, self::LIB_JQUERY_UI_WIDGETS_DIALOG, self::LIB_JQUERY_UI_WIDGETS_SLIDER),	// 画像リサイズが実行できないバグの対応。jQuery UIよりも前にBootstrapを読ませる必要がある。(2015/1/25)
