@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2017 Magic3 Project.
+ * @copyright  Copyright 2006-2018 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -20,6 +20,7 @@ class BaseFrameContainer extends Core
 {
 	protected $_db;	// DB接続オブジェクト
 	private $joomlaBufArray = array();			// Joomla!データ受け渡し用
+	private $templateCustomObj;				// テンプレートカスタマイズパラメータオブジェクト
 	const SYSTEM_TEMPLATE = '_system';		// システム画面用テンプレート
 	const M_ADMIN_TEMPLATE = 'm/_admin';	// 携帯用管理画面テンプレート
 	const ERR_MESSAGE_ACCESS_DENY = 'Access denied.';		// ウィジェットアクセスエラーのメッセージ
@@ -357,6 +358,9 @@ class BaseFrameContainer extends Core
 			$createPage = false;		// ウィジェット単体処理モードに設定
 		} else if ($cmd == M3_REQUEST_CMD_CSS){		// CSS生成
 		
+		} else if ($cmd == M3_REQUEST_CMD_CONFIG_TEMPLATE){		// テンプレートの設定
+			$createPage = false;		// ウィジェット単体処理モードに設定
+			$this->gPage->showWidget();	// ウィジェット表示
 		} else if ($this->gEnv->isServerConnector()){		// サーバ接続の場合
 			$createPage = false;		// ウィジェット単体処理モードに設定
 		}
@@ -565,6 +569,11 @@ class BaseFrameContainer extends Core
 				// 指定のウィジェットを実行
 				if ($cmd == M3_REQUEST_CMD_CONFIG_WIDGET){		// ウィジェット設定のとき
 					$widgetIndexFile = $this->gEnv->getWidgetsPath() . '/' . $widgetId . '/admin/' . M3_FILENAME_INDEX;		// 管理用画面
+				} else if ($cmd == M3_REQUEST_CMD_CONFIG_TEMPLATE){		// テンプレート設定の場合
+					$templateId = $request->trimValueOf(M3_REQUEST_PARAM_TEMPLATE_ID);		// テンプレートIDを取得
+					
+					// テンプレート設定画面を取得
+					$widgetIndexFile = $this->gEnv->getTemplatesPath() . '/' . $templateId . '/admin/' . M3_FILENAME_INDEX;
 				} else {
 					$widgetIndexFile = $this->gEnv->getWidgetsPath() . '/' . $widgetId . '/' . M3_FILENAME_INDEX;
 				}
@@ -613,6 +622,7 @@ class BaseFrameContainer extends Core
 			
 			if ($cmd == M3_REQUEST_CMD_SHOW_WIDGET ||		// ウィジェットの単体表示
 				$cmd == M3_REQUEST_CMD_CONFIG_WIDGET ||		// ウィジェット設定のとき
+				$cmd == M3_REQUEST_CMD_CONFIG_TEMPLATE ||		// テンプレートの設定
 				($cmd == M3_REQUEST_CMD_DO_WIDGET && !empty($openBy))){		// ウィンドウオープンタイプ指定でウィジェット単体実行のとき
 				
 				// 現在の出力内容を取得し、一旦内容をクリア
@@ -1432,6 +1442,28 @@ class BaseFrameContainer extends Core
 			return false;
 		}
 	}
+	/***********************************************************************************
+	 * 以下、テンプレート専用
+	 ***********************************************************************************/
+	/**
+	 * [カスタムテンプレート用] テンプレートのヘッダ部に出力するCSSのデータを取得
+	 *
+	 * @return string				CSS出力データ(HTMLタグ形式、または「/」から始まるCSSファイルの相対パス)。設定なしの場合は空文字列。
+	 */
+	function getCustomTemplateHeadCssData()
+	{
+		global $gEnvManager;
+		
+		if (!isset($this->templateCustomObj)){
+			$optionParams = $gEnvManager->getCurrentTemplateCustomParam();
+			if (empty($optionParams)){
+				$this->templateCustomObj = array();
+			} else {
+				$this->templateCustomObj = unserialize($optionParams);		// 連想配列に変換
+			}
+		}
+		return $this->templateCustomObj['head_css_data'];
+	}
 	/***********************************************************************************
 	 * 以下、Joomla!v1.5テンプレート専用
 	 ***********************************************************************************/
