@@ -673,16 +673,17 @@ function wp_magic_quotes() {
  * @since 1.2.0
  * @access private
  */
-//function shutdown_action_hook() {
-//	/**
-//	 * Fires just before PHP shuts down execution.
-//	 *
-//	 * @since 1.2.0
-//	 */
-//	do_action( 'shutdown' );
-//
+function shutdown_action_hook() {
+	/**
+	 * Fires just before PHP shuts down execution.
+	 *
+	 * @since 1.2.0
+	 */
+	// WooCommerceセッション保存処理等
+	do_action( 'shutdown' );
+
 //	wp_cache_close();
-//}
+}
 
 /**
  * Copy an object.
@@ -1054,6 +1055,7 @@ function wp_is_ini_value_changeable( $setting ) {
  * @return bool True if it's a WordPress Ajax request, false otherwise.
  */
 function wp_doing_ajax() {
+	// AJAX起動かどうかは$_GET['wc-ajax']の値があるかどうかで判断される
 	/**
 	 * Filters whether the current request is a WordPress Ajax request.
 	 *
