@@ -3,7 +3,15 @@
  * @author Sergio Jovani <lesergi@gmail.com>
  * @version 2014-12-19
  */
-if (elFinder && elFinder.prototype && typeof(elFinder.prototype.i18) == 'object') {
+(function(root, factory) {
+	if (typeof define === 'function' && define.amd) {
+		define(['elfinder'], factory);
+	} else if (typeof exports !== 'undefined') {
+		module.exports = factory(require('elfinder'));
+	} else {
+		factory(root.elFinder);
+	}
+}(this, function(elFinder) {
 	elFinder.prototype.i18.ca = {
 		translator : 'Sergio Jovani &lt;lesergi@gmail.com&gt;',
 		language   : 'Català',
@@ -75,7 +83,7 @@ if (elFinder && elFinder.prototype && typeof(elFinder.prototype.i18) == 'object'
 			'errArcMaxSize'        : 'Els fitxers de l\'arxiu excedeixen la mida màxima permesa.',
 			'errResize'            : 'No s\'ha pogut redimensionar "$1".',
 			'errResizeDegree' : 'Invalid rotate degree.',
-			'errResizeRotate' : 'Image dose not rotated.',
+			'errResizeRotate' : 'Unable to rotate image.',
 			'errResizeSize' : 'Invalid image size.',
 			'errResizeNoChange' : 'Image size not changed.',
 			'errUsupportType'      : 'El tipus de fitxer no està suportat.',
@@ -303,6 +311,7 @@ if (elFinder && elFinder.prototype && typeof(elFinder.prototype.i18) == 'object'
 			'kindTAR'         : 'Arxiu TAR',
 			'kindGZIP'        : 'Arxiu GZIP',
 			'kindBZIP'        : 'Arxiu BZIP',
+			'kindXZ'          : 'Arxiu XZ',
 			'kindZIP'         : 'Arxiu ZIP',
 			'kindRAR'         : 'Arxiu RAR',
 			'kindJAR'         : 'Fitxer JAR de Java',
@@ -362,5 +371,5 @@ if (elFinder && elFinder.prototype && typeof(elFinder.prototype.i18) == 'object'
 			'kindVideoOGG'    : 'Fitxer de vídeo Ogg'
 		}
 	};
-}
+}));
 
