@@ -21,7 +21,14 @@
  *				'quality'        => 95,         // JPEG image save quality
  *				'transparency'   => 70,         // Water mark image transparency ( other than PNG )
  *				'targetType'     => IMG_GIF|IMG_JPG|IMG_PNG|IMG_WBMP, // Target image formats ( bit-field )
- *				'targetMinPixel' => 200         // Target image minimum pixel size
+ *				'targetMinPixel' => 200,        // Target image minimum pixel size
+ *				'interlace'      => IMG_GIF|IMG_JPG, // Set interlacebit image formats ( bit-field )
+ *				'offDropWith'    => null,       // Enabled by default. To disable it if it is dropped with pressing the meta key
+ *				                                // Alt: 8, Ctrl: 4, Meta: 2, Shift: 1 - sum of each value
+ *				                                // In case of using any key, specify it as an array
+ *				'onDropWith'     => null        // Disabled by default. To enable it if it is dropped with pressing the meta key
+ *				                                // Alt: 8, Ctrl: 4, Meta: 2, Shift: 1 - sum of each value
+ *				                                // In case of using any key, specify it as an array
  *			)
  *		),
  *		// each volume configure (optional)
@@ -39,7 +46,14 @@
  *						'quality'        => 95,         // JPEG image save quality
  *						'transparency'   => 70,         // Water mark image transparency ( other than PNG )
  *						'targetType'     => IMG_GIF|IMG_JPG|IMG_PNG|IMG_WBMP, // Target image formats ( bit-field )
- *						'targetMinPixel' => 200         // Target image minimum pixel size
+ *						'targetMinPixel' => 200,        // Target image minimum pixel size
+ *						'interlace'      => IMG_GIF|IMG_JPG, // Set interlacebit image formats ( bit-field )
+ *        				'offDropWith'    => null,       // Enabled by default. To disable it if it is dropped with pressing the meta key
+ *        				                                // Alt: 8, Ctrl: 4, Meta: 2, Shift: 1 - sum of each value
+ *        				                                // In case of using any key, specify it as an array
+ *        				'onDropWith'     => null        // Disabled by default. To enable it if it is dropped with pressing the meta key
+ *						                                // Alt: 8, Ctrl: 4, Meta: 2, Shift: 1 - sum of each value
+ *						                                // In case of using any key, specify it as an array
  *					)
  *				)
  *			)
@@ -50,9 +64,8 @@
  * @author Naoki Sawada
  * @license New BSD
  */
-class elFinderPluginWatermark {
+class elFinderPluginWatermark extends elFinderPlugin {
 
-	private $opts = array();
 	private $watermarkImgInfo = null;
 
 	public function __construct($opts) {
@@ -64,35 +77,62 @@ class elFinderPluginWatermark {
 			'quality'        => 95,         // JPEG image save quality
 			'transparency'   => 70,         // Water mark image transparency ( other than PNG )
 			'targetType'     => IMG_GIF|IMG_JPG|IMG_PNG|IMG_WBMP, // Target image formats ( bit-field )
-			'targetMinPixel' => 200         // Target image minimum pixel size
+			'targetMinPixel' => 200,        // Target image minimum pixel size
+			'interlace'      => IMG_GIF|IMG_JPG, // Set interlacebit image formats ( bit-field )
+			'offDropWith'    => null        // To disable it if it is dropped with pressing the meta key
+			                                // Alt: 8, Ctrl: 4, Meta: 2, Shift: 1 - sum of each value
+			                                // In case of using any key, specify it as an array
 		);
 
 		$this->opts = array_merge($defaults, $opts);
 
 	}
 
-	public function onUpLoadPreSave(&$path, &$name, $src, $elfinder, $volume) {
+	public function onUpLoadPreSave(&$thash, &$name, $src, $elfinder, $volume) {
+		$opts = $this->getCurrentOpts($volume);
 		
-		$opts = $this->opts;
-		$volOpts = $volume->getOptionsPlugin('Watermark');
-		if (is_array($volOpts)) {
-			$opts = array_merge($this->opts, $volOpts);
-		}
-		
-		if (! $opts['enable']) {
+		if (! $this->iaEnabled($opts)) {
 			return false;
 		}
 		
-		$srcImgInfo = getimagesize($src);
-		if ($srcImgInfo === false) {
+		$imageType = null;
+		$srcImgInfo = null;
+		if (extension_loaded('fileinfo') && function_exists('mime_content_type')) {
+			$mime = mime_content_type($src);
+			if (substr($mime, 0, 5) !== 'image') {
+				return false;
+			}
+		}
+		if (extension_loaded('exif') && function_exists('exif_imagetype')) {
+			$imageType = exif_imagetype($src);
+		} else {
+			$srcImgInfo = getimagesize($src);
+			if ($srcImgInfo === false) {
+				return false;
+			}
+			$imageType = $srcImgInfo[2];
+		}
+		
+		// check target image type
+		$imgTypes = array(
+				IMAGETYPE_GIF  => IMG_GIF,
+				IMAGETYPE_JPEG => IMG_JPEG,
+				IMAGETYPE_PNG  => IMG_PNG,
+				IMAGETYPE_BMP  => IMG_WBMP,
+				IMAGETYPE_WBMP => IMG_WBMP
+		);
+		if (! isset($imgTypes[$imageType]) || ! ($opts['targetType'] & $imgTypes[$imageType])) {
 			return false;
 		}
 		
 		// check Animation Gif
-		if (elFinder::isAnimationGif($src)) {
+		if ($imageType === IMAGETYPE_GIF && elFinder::isAnimationGif($src)) {
+			return false;
+		}
+		// check Animation Png
+		if ($imageType === IMAGETYPE_PNG && elFinder::isAnimationPng($src)) {
 			return false;
 		}
-		
 		// check water mark image
 		if (! file_exists($opts['source'])) {
 			$opts['source'] = dirname(__FILE__) . "/" . $opts['source'];
@@ -106,24 +146,16 @@ class elFinderPluginWatermark {
 			return false;
 		}
 		
+		if (! $srcImgInfo) {
+			$srcImgInfo = getimagesize($src);
+		}
+		
 		$watermark = $opts['source'];
 		$marginLeft = $opts['marginRight'];
 		$marginBottom = $opts['marginBottom'];
 		$quality = $opts['quality'];
 		$transparency = $opts['transparency'];
 
-		// check target image type
-		$imgTypes = array(
-			IMAGETYPE_GIF  => IMG_GIF,
-			IMAGETYPE_JPEG => IMG_JPEG,
-			IMAGETYPE_PNG  => IMG_PNG,
-			IMAGETYPE_BMP  => IMG_WBMP,
-			IMAGETYPE_WBMP => IMG_WBMP
-		);
-		if (! ($opts['targetType'] & $imgTypes[$srcImgInfo[2]])) {
-			return false;
-		}
-		
 		// check target image size
 		if ($opts['targetMinPixel'] > 0 && $opts['targetMinPixel'] > min($srcImgInfo[0], $srcImgInfo[1])) {
 			return false;
@@ -134,16 +166,21 @@ class elFinderPluginWatermark {
 		$dest_x = $srcImgInfo[0] - $watermark_width - $marginLeft;
 		$dest_y = $srcImgInfo[1] - $watermark_height - $marginBottom;
 		
+		// check interlace
+		$opts['interlace'] = ($opts['interlace'] & $imgTypes[$imageType]);
+		
 		if (class_exists('Imagick', false)) {
-			return $this->watermarkPrint_imagick($src, $watermark, $dest_x, $dest_y, $quality, $transparency, $watermarkImgInfo);
+			return $this->watermarkPrint_imagick($src, $watermark, $dest_x, $dest_y, $quality, $transparency, $watermarkImgInfo, $opts);
 		} else {
-			return $this->watermarkPrint_gd($src, $watermark, $dest_x, $dest_y, $quality, $transparency, $watermarkImgInfo, $srcImgInfo);
+			elFinder::expandMemoryForGD(array($watermarkImgInfo, $srcImgInfo));
+			return $this->watermarkPrint_gd($src, $watermark, $dest_x, $dest_y, $quality, $transparency, $watermarkImgInfo, $srcImgInfo, $opts);
 		}
 	}
 	
-	private function watermarkPrint_imagick($src, $watermark, $dest_x, $dest_y, $quality, $transparency, $watermarkImgInfo) {
+	private function watermarkPrint_imagick($src, $watermark, $dest_x, $dest_y, $quality, $transparency, $watermarkImgInfo, $opts) {
 		
 		try {
+		
 			// Open the original image
 			$img = new Imagick($src);
 			
@@ -164,6 +201,9 @@ class elFinderPluginWatermark {
 				$img->setCompressionQuality($quality);
 			}
 			
+			// set interlace
+			$opts['interlace'] && $img->setInterlaceScheme(Imagick::INTERLACE_PLANE);
+			
 			$result = $img->writeImage($src);
 			
 			$img->clear();
@@ -173,48 +213,50 @@ class elFinderPluginWatermark {
 			
 			return $result ? true : false;
 		} catch (Exception $e) {
+			$ermsg = $e->getMessage();
+			$ermsg && trigger_error($ermsg);
 			return false;
 		}
 	}
 	
-	private function watermarkPrint_gd($src, $watermark, $dest_x, $dest_y, $quality, $transparency, $watermarkImgInfo, $srcImgInfo) {
+	private function watermarkPrint_gd($src, $watermark, $dest_x, $dest_y, $quality, $transparency, $watermarkImgInfo, $srcImgInfo, $opts) {
 		
 		$watermark_width = $watermarkImgInfo[0];
 		$watermark_height = $watermarkImgInfo[1];
-				
+
 		$ermsg = '';
 		switch ($watermarkImgInfo['mime']) {
 			case 'image/gif':
 				if (imagetypes() & IMG_GIF) {
 					$oWatermarkImg = imagecreatefromgif($watermark);
 				} else {
-					$ermsg = 'GIF images are not supported';
+					$ermsg = 'GIF images are not supported as watermark image';
 				}
 				break;
 			case 'image/jpeg':
 				if (imagetypes() & IMG_JPG) {
 					$oWatermarkImg = imagecreatefromjpeg($watermark) ;
 				} else {
-					$ermsg = 'JPEG images are not supported';
+					$ermsg = 'JPEG images are not supported as watermark image';
 				}
 				break;
 			case 'image/png':
 				if (imagetypes() & IMG_PNG) {
 					$oWatermarkImg = imagecreatefrompng($watermark) ;
 				} else {
-					$ermsg = 'PNG images are not supported';
+					$ermsg = 'PNG images are not supported as watermark image';
 				}
 				break;
 			case 'image/wbmp':
 				if (imagetypes() & IMG_WBMP) {
 					$oWatermarkImg = imagecreatefromwbmp($watermark);
 				} else {
-					$ermsg = 'WBMP images are not supported';
+					$ermsg = 'WBMP images are not supported as watermark image';
 				}
 				break;
 			default:
 				$oWatermarkImg = false;
-				$ermsg = $watermarkImgInfo['mime'].' images are not supported';
+				$ermsg = $watermarkImgInfo['mime'].' images are not supported as watermark image';
 				break;
 		}
 		
@@ -224,38 +266,39 @@ class elFinderPluginWatermark {
 					if (imagetypes() & IMG_GIF) {
 						$oSrcImg = imagecreatefromgif($src);
 					} else {
-						$ermsg = 'GIF images are not supported';
+						$ermsg = 'GIF images are not supported as source image';
 					}
 					break;
 				case 'image/jpeg':
 					if (imagetypes() & IMG_JPG) {
 						$oSrcImg = imagecreatefromjpeg($src) ;
 					} else {
-						$ermsg = 'JPEG images are not supported';
+						$ermsg = 'JPEG images are not supported as source image';
 					}
 					break;
 				case 'image/png':
 					if (imagetypes() & IMG_PNG) {
 						$oSrcImg = imagecreatefrompng($src) ;
 					} else {
-						$ermsg = 'PNG images are not supported';
+						$ermsg = 'PNG images are not supported as source image';
 					}
 					break;
 				case 'image/wbmp':
 					if (imagetypes() & IMG_WBMP) {
 						$oSrcImg = imagecreatefromwbmp($src);
 					} else {
-						$ermsg = 'WBMP images are not supported';
+						$ermsg = 'WBMP images are not supported as source image';
 					}
 					break;
 				default:
 					$oSrcImg = false;
-					$ermsg = $srcImgInfo['mime'].' images are not supported';
+					$ermsg = $srcImgInfo['mime'].' images are not supported as source image';
 					break;
 			}
 		}
 		
 		if ($ermsg || false === $oSrcImg || false === $oWatermarkImg) {
+			$ermsg && trigger_error($ermsg);
 			return false;
 		}
 		
@@ -272,6 +315,9 @@ class elFinderPluginWatermark {
 			imagecopymerge($oSrcImg, $oWatermarkImg, $dest_x, $dest_y, 0, 0, $watermark_width, $watermark_height, $transparency);
 		}
 		
+		// set interlace
+		$opts['interlace'] && imageinterlace($oSrcImg, true);
+		
 		switch ($srcImgInfo['mime']) {
 			case 'image/gif':
 				imagegif($oSrcImg, $src);
