@@ -123,7 +123,7 @@ CKEDITOR.editorConfig = function( config ) {
 		{ name: 'tools', items: [ 'Maximize', 'ShowBlocks', 'Source' ] },
 		{ name: 'clipboard', items: [ 'Templates', '-', 'Cut', 'Copy', 'Paste', 'PasteText', 'PasteFromWord', '-', 'Undo', 'Redo' ] },
 		{ name: 'editing', items : [ 'Find','Replace','-','SelectAll' ] },
-		{ name: 'insert', items: [ 'Image', 'Flash', 'YouTube', 'Googlemaps', 'Table', 'HorizontalRule' ] },
+		{ name: 'insert', items: [ 'Image', 'YouTube', 'Googlemaps', 'Table', 'HorizontalRule' ] },
 		{ name: 'colors', items : [ 'TextColor', 'BGColor' ] },
 		{ name: 'others', items: [ 'LinkInfo', 'M3Templates' ] },
 		'/',
@@ -152,20 +152,13 @@ CKEDITOR.editorConfig = function( config ) {
 	config.allowedContent = true;		// ACF(Advanced Content Filter)を使用しない。SCRIPT,IFRAMEタグ等許可。
 //	config.extraAllowedContent = 'iframe';
 //	config.autoGrow_maxHeight = 800;		// 指定サイズまで入力に合わせて拡大
-	
-	// KCFinderの設定
-	if (!jQuery().elfinder){			// elFinderが使用できない場合
-		config.filebrowserBrowseUrl			= M3_ROOT_URL + '/scripts/kcfinder-2.51/browse.php?type=file';
-		config.filebrowserImageBrowseUrl	= M3_ROOT_URL + '/scripts/kcfinder-2.51/browse.php?type=image';
-		config.filebrowserFlashBrowseUrl	= M3_ROOT_URL + '/scripts/kcfinder-2.51/browse.php?type=flash';
-	}
 };
 CKEDITOR.on('dialogDefinition', function(ev){
 	var dialogName = ev.data.name;
 	var dialogDefinition = ev.data.definition;
 	var dialog = dialogDefinition.dialog;
 	
-	if (dialogName == 'image' || dialogName == 'flash'){
+	if (dialogName == 'image'){
 		dialogDefinition.removeContents('Upload');	// 「アップロード」タブ削除
 	}
 	
@@ -187,9 +180,6 @@ CKEDITOR.on('dialogDefinition', function(ev){
 					case 'image':
 						title = '画像を選択';
 						break;
-					case 'flash':
-						title = 'Flashを選択';
-						break;
 					default:
 						title = 'ファイルを選択';
 						break;
@@ -205,7 +195,7 @@ CKEDITOR.on('dialogDefinition', function(ev){
 						},
 						create: function(event, ui){
 							var option = '';
-							if (dialogName == 'image' || dialogName == 'flash'){
+							if (dialogName == 'image'){
 								option = '?dirtype=' + dialogName;
 							} else if (dialogName == 'm3link'){
 								option = '?dirtype=file';
