@@ -67,8 +67,8 @@ class admin_menu4WidgetContainer extends BaseAdminWidgetContainer
 	const MAINMENU_COL_STYLE = 'col-md-';	// Bootstrapのカラムクラス
 	const MENUBAR_HEIGHT = 60;			// メインメニューバーの高さ
 	const SUB_MENUBAR_HEIGHT = 50;			// サブメニューバーの高さ
-	const SEL_MENU_ID = 'admin_menu';		// メニュー変換対象メニューバーID
-	const TREE_MENU_TASK	= 'menudef';	// メニュー管理画面(多階層)
+//	const SEL_MENU_ID = 'admin_menu';		// メニュー変換対象メニューバーID
+//	const TREE_MENU_TASK	= 'menudef';	// メニュー管理画面(多階層)
 	
 	// DB定義値
 	const CF_SITE_IN_PUBLIC			= 'site_in_public';			// サイト公開状況
@@ -890,7 +890,8 @@ class admin_menu4WidgetContainer extends BaseAdminWidgetContainer
 			$iconUrl = $this->gEnv->getRootUrl() . self::MENU_ICON_FILE;		// メニュー定義画面アイコン
 			
 			// メニュー定義の編集画面のタイプを取得
-			$isHierMenu = $this->getMenuIsHider();			// メニュー定義編集画面が多階層タイプであるかどうか
+//			$isHierMenu = $this->getMenuIsHider();			// メニュー定義編集画面が多階層タイプであるかどうか
+			$isHierMenu = $this->gSystem->isSiteMenuHier();
 		
 			// メニュー定義画面のURLを作成
 			$taskValue = 'menudef';
@@ -949,13 +950,13 @@ class admin_menu4WidgetContainer extends BaseAdminWidgetContainer
 	 *
 	 * @return bool				true=多階層、false=単階層
 	 */
-	function getMenuIsHider()
+/*	function getMenuIsHider()
 	{
 		$isHier = false;	// 多階層メニューかどうか
 		$ret = $this->db->getNavItemsByTask(self::SEL_MENU_ID, self::TREE_MENU_TASK, $row);
 		if ($ret) $isHier = true;
 
 		return $isHier;
-	}
+	}*/
 }
 ?>
