@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: bbs_2ch_mainWidgetContainer.php 2930 2010-03-17 14:19:10Z fishbone $
+ * @version    SVN: $Id: bbs_2ch_mainWidgetContainer.php 4026 2011-03-10 07:40:49Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/bbs_2ch_mainBaseWidgetContainer.php');
@@ -46,9 +46,16 @@ class bbs_2ch_mainWidgetContainer extends bbs_2ch_mainBaseWidgetContainer
 			$threadId = $request->trimValueOf(M3_REQUEST_PARAM_BBS_THREAD_ID);
 			if (empty($threadId)) $request->trimValueOf(M3_REQUEST_PARAM_BBS_THREAD_ID_SHORT);
 			
+			// 検索キーワードを取得
+			$keyword = $request->trimValueOf(M3_REQUEST_PARAM_KEYWORD);
+			
 			// スレッドIDが設定されているときはスレッド表示タスクを設定
 			if (empty($threadId)){
-				$task = self::DEFAULT_TASK;
+				if (empty($keyword)){
+					$task = self::DEFAULT_TASK;
+				} else {		// 検索キーワードが設定されている場合
+					$task = self::TASK_SUBJECT;		// 件名一覧
+				}
 			} else {
 				$task = self::TASK_READ_THREAD;		// スレッド表示
 			}
