@@ -22,7 +22,8 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 	private $db;	// DB接続オブジェクト
 	private $entryDays = array();		// 投稿のあった日にち
 	private $css;	// カレンダー用CSS
-	const DEFAULT_TITLE = 'ブログカレンダー';			// デフォルトのウィジェットタイトル
+	const DEFAULT_TITLE = 'ブログカレンダー';					// デフォルトのウィジェットタイトル
+	const WORDPRESS_WIDGET_CLASS = 'widget_calendar';			// WordPress用ウィジェットクラス名
 		
 	/**
 	 * コンストラクタ
@@ -194,6 +195,9 @@ class blog_calendar_boxWidgetContainer extends BaseWidgetContainer
 			$calendarData .= '</tbody>' . M3_NL;
 			$calendarData .= '</table>' . M3_NL;
 			$calendarData = '<div class="calendar_wrap">' . $calendarData . '</div>';
+			
+			// ##### ウィジェットクラス名追加 #####
+			$this->gEnv->setWpWidgetClass(self::WORDPRESS_WIDGET_CLASS);
 		} else {
 			$calendarData .= '<div align="center">' . M3_NL;
 			if (empty($prevUrl)){		// 前の月のリンクなしのとき
