@@ -26,6 +26,7 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 	private $langId;			// 言語
 	private $unitTypeId;		// 選択単位
 	private $currency;			// 通貨
+	private $defaultCurrencyId;	// デフォルトの通貨ID
 	private $taxType;			// 税種別
 	private $ecObj;			// 共通ECオブジェクト
 	private $categoryListData;		// 商品カテゴリー
@@ -36,7 +37,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 	private $imageTypes;			// 画像タイプ
 	private $categoryCount;	// カテゴリー選択可能数
 	const MAX_HIER_LEVEL = 20;		// カテゴリー階層最大値
-	const STANDARD_PRICE = 'selling';		// 通常価格
+	const REGULAR_PRICE = 'regular';		// 販売価格
+	const SALE_PRICE = 'sale';		// セール価格
 	const PRODUCT_IMAGE_MEDIUM = 'standard-product';		// 中サイズ商品画像ID
 	const PRODUCT_IMAGE_SMALL = 'small-product';		// 小サイズ商品画像ID
 	const PRODUCT_IMAGE_LARGE = 'large-product';		// 大サイズ商品画像ID
@@ -75,6 +77,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 		// EC用共通オブジェクト取得
 		$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);
 		
+		$this->defaultCurrencyId = $this->ecObj->getDefaultCurrency();	// デフォルトの通貨ID
+		
 		$this->sortKeyType = array('index'/*表示順*/, 'stock'/*在庫数*/, 'id'/*商品ID*/, 'date'/*更新日時*/, 'name'/*商品名*/, 'code'/*商品コード*/, 'price'/*商品価格*/, 'visible'/*公開状態*/);
 		$this->imageTypes = array('s', 'm', 'l');			// 画像タイプ
 		$this->categoryCount = self::$_mainDb->getConfig(ec_mainCommonDef::CF_E_CATEGORY_SELECT_COUNT);	// カテゴリー選択可能数
@@ -463,7 +467,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 		$this->taxType = $request->trimValueOf('item_tax_type');					// 税種別
 		$adminNote = $request->trimValueOf('item_admin_note');		// 管理者用備考
 		$price = $request->trimValueOf('item_price');		// 価格
-		
+		$salePrice = $request->trimValueOf('item_sale_price');		// セール価格
+
 		// 画像のパスをマクロ表記パスに直す
 /*		$imageUrl_s = $request->trimValueOf('imageurl_s');		// 小画像
 		if (!empty($imageUrl_s)){
@@ -509,6 +514,10 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 			$this->checkNumericF($unitQuantity, '数量');
 			$this->checkNumeric($stockCount, '表示在庫数');
 			$this->checkNumericF($price, '商品価格');
+			$this->checkNumericF($salePrice, 'セール価格', true);
+			if (!empty($salePrice) && floatval($salePrice) >= floatval($price)){
+				$this->setUserErrorMsg('セール価格は通常価格よりも小さく設定してください');
+			}
 			if (empty($this->unitTypeId)) $this->setUserErrorMsg('販売単位が選択されていません');
 
 			// エラーなしの場合は、データを登録
@@ -523,8 +532,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$otherParams['pt_product_type'] = 1;				// 商品種別(1=単品商品、2=セット商品、3=オプション商品)
 				$otherParams['pt_unit_type_id'] = $this->unitTypeId;	// 選択単位
 				$otherParams['pt_unit_quantity'] = $unitQuantity;		// 数量
-				$otherParams['pt_description'] = $description;		// 説明
-				$otherParams['pt_description_short'] = $description_short;	// 簡易説明
+				$otherParams['pt_html'] = $description;		// 説明
+				$otherParams['pt_description'] = $description_short;	// 簡易説明
 				//$otherParams['pt_search_keyword'] = $keyword;		// 検索キーワード
 				$otherParams['pt_meta_keywords'] = $metaKeyword;	// METAタグ用キーワード
 				$otherParams['pt_site_url'] = $url;			// 詳細情報URL
@@ -538,7 +547,13 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$priceArray = array();
 				$startDt = $this->gEnv->getInitValueOfTimestamp();
 				$endDt = $this->gEnv->getInitValueOfTimestamp();
-				$priceArray[] = array(self::STANDARD_PRICE, $this->currency, $price, $startDt, $endDt);		// 単品商品で追加
+				$priceArray[] = array(self::REGULAR_PRICE, $this->defaultCurrencyId, $price, $startDt, $endDt);		// 単品商品で追加
+				// セール価格
+				if (self::$_configArray[ec_mainCommonDef::CF_E_USE_SALE_PRICE] && floatval($salePrice) > 0){
+					$priceArray[] = array(self::SALE_PRICE, $this->defaultCurrencyId, floatval($salePrice), $startDt, $endDt);
+				} else {
+					$priceArray[] = array(self::SALE_PRICE, $this->defaultCurrencyId, null/*削除*/, $startDt, $endDt);			// 0の場合はレコードを削除
+				}
 				
 				// 画像情報の作成
 				$productId = $this->db->getNextProductId();		// 次の商品ID取得
@@ -618,6 +633,10 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 			$this->checkNumericF($unitQuantity, '数量');
 			$this->checkNumeric($stockCount, '表示在庫数');
 			$this->checkNumericF($price, '商品価格');
+			$this->checkNumericF($salePrice, 'セール価格', true);
+			if (!empty($salePrice) && floatval($salePrice) >= floatval($price)){
+				$this->setUserErrorMsg('セール価格は通常価格よりも小さく設定してください');
+			}
 			if (empty($this->unitTypeId)) $this->setUserErrorMsg('販売単位が選択されていません');
 			
 			// エラーなしの場合は、データを登録
@@ -632,8 +651,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$otherParams['pt_product_type'] = 1;				// 商品種別(1=単品商品、2=セット商品、3=オプション商品)
 				$otherParams['pt_unit_type_id'] = $this->unitTypeId;	// 選択単位
 				$otherParams['pt_unit_quantity'] = $unitQuantity;		// 数量
-				$otherParams['pt_description'] = $description;		// 説明
-				$otherParams['pt_description_short'] = $description_short;	// 簡易説明
+				$otherParams['pt_html'] = $description;		// 説明
+				$otherParams['pt_description'] = $description_short;	// 簡易説明
 				//$otherParams['pt_search_keyword'] = $keyword;		// 検索キーワード
 				$otherParams['pt_meta_keywords'] = $metaKeyword;	// METAタグ用キーワード
 				$otherParams['pt_site_url'] = $url;			// 詳細情報URL
@@ -647,7 +666,13 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$priceArray = array();
 				$startDt = $this->gEnv->getInitValueOfTimestamp();
 				$endDt = $this->gEnv->getInitValueOfTimestamp();
-				$priceArray[] = array(self::STANDARD_PRICE, $this->currency, $price, $startDt, $endDt);		// 単品商品で追加
+				$priceArray[] = array(self::REGULAR_PRICE, $this->defaultCurrencyId, $price, $startDt, $endDt);		// 単品商品で追加
+				// セール価格
+				if (self::$_configArray[ec_mainCommonDef::CF_E_USE_SALE_PRICE] && floatval($salePrice) > 0){
+					$priceArray[] = array(self::SALE_PRICE, $this->defaultCurrencyId, floatval($salePrice), $startDt, $endDt);
+				} else {
+					$priceArray[] = array(self::SALE_PRICE, $this->defaultCurrencyId, null/*削除*/, $startDt, $endDt);			// 0の場合はレコードを削除
+				}
 				
 				// 画像情報の作成
 				// 商品情報取得
@@ -702,8 +727,6 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$statusArray[] = array(self::PRODUCT_STATUS_SUGGEST, $suggest);		// おすすめ
 				
 				// 商品情報を取得
-				//$ret = $this->db->getProductBySerial($this->serialNo, $row, $row2, $row3, $row4, $row5);
-				//if ($ret) $productId = $row['pt_id'];	// 商品ID
 				if ($ret) $ret = $this->db->updateProduct($this->serialNo, $productId, $this->langId, $otherParams, 
 												$stockCount, $priceArray, $imageArray, $statusArray, $this->categoryArray, $newSerial);
 				if ($ret){
@@ -927,8 +950,8 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$delivType = $row['pt_deliv_type'];		// 配送タイプ
 				$delivPrice = $row['pt_deliv_fee'];		// 配送単価
 				$delivWeight = $row['pt_weight'];		// 配送基準重量
-				$description = $row['pt_description'];			// 説明
-				$description_short = $row['pt_description_short'];		// 簡易説明
+				$description = $row['pt_html'];			// 説明
+				$description_short = $row['pt_description'];		// 簡易説明
 				//$keyword = $row['pt_search_keyword'];					// 検索キーワード
 				$metaKeyword = $row['pt_meta_keywords'];	// METAタグ用キーワード
 				$url = $row['pt_site_url'];							// 詳細情報URL
@@ -938,10 +961,16 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$updateDt = $this->convertToDispDateTime($row['pt_create_dt']);	// 更新日時
 			
 				// 価格を取得
-				$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
+				$priceArray = $this->getPrice($row2, self::REGULAR_PRICE, $this->defaultCurrencyId);
 				$price = $priceArray['pp_price'];	// 価格
 				$this->currency = $priceArray['pp_currency_id'];	// 通貨
-			
+				// セール価格
+				$salePrice = '';
+				if (self::$_configArray[ec_mainCommonDef::CF_E_USE_SALE_PRICE]){			// セール価格を使用する場合
+					$priceArray = $this->getPrice($row2, self::SALE_PRICE, $this->defaultCurrencyId);
+					if (floatval($priceArray['pp_price']) > 0) $salePrice = $priceArray['pp_price'];	// 価格
+				}
+
 				// 画像を取得
 				$imageArray = $this->getImage($row3, self::PRODUCT_IMAGE_SMALL);// 商品画像小
 				$imageUrl_s = $imageArray['im_url'];	// URL
@@ -980,6 +1009,7 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 				$new = 0;// 新規
 				$suggest = 0;// おすすめ
 				$price = '';	// 価格
+				$salePrice = '';// セール価格
 				$this->currency	= $this->ecObj->getDefaultCurrency();		// 通貨
 				$this->unitTypeId = self::DEFAULT_UNIT_TYPE_ID;	// 単位
 				$unitQuantity = 1;		// 数量
@@ -1033,10 +1063,14 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 		// カテゴリーメニューを作成
 		$this->createCategoryMenu($this->categoryCount);
 		
+		// その他価格の表示制御
+		if (self::$_configArray[ec_mainCommonDef::CF_E_USE_SALE_PRICE]) $this->tmpl->setAttribute('other_price', 'visibility', 'visible');
+		
 		// 各種価格を求める
 		$price = $this->ecObj->getCurrencyPrice($price);	// 端数調整
-		$this->ecObj->setCurrencyType($this->currency, $this->langId);		// 通貨設定
-		$this->ecObj->setTaxType($this->taxType, $this->langId);		// 税種別設定
+		if ($salePrice != '') $salePrice = $this->ecObj->getCurrencyPrice($salePrice);	// 端数調整
+		$this->ecObj->setCurrencyType($this->defaultCurrencyId, $this->langId);		// 通貨設定
+		$this->ecObj->setTaxType($this->taxType);		// 税種別設定
 		$totalPrice = $this->ecObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
 		$delivPrice = $this->ecObj->getCurrencyPrice($delivPrice);	// 端数調整
 		
@@ -1060,6 +1094,7 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 		$this->tmpl->addVar("_widget", "url", $url);				// 詳細情報URL
 		$this->tmpl->addVar("_widget", "admin_note", $adminNote);			// 管理者用備考
 		$this->tmpl->addVar("_widget", "price", $price);		// 価格
+		$this->tmpl->addVar("other_price", "sale_price", $salePrice);		// セール価格
 		$this->tmpl->addVar("_widget", "price_with_tax", $dispPrice);		// 税込価格
 		$this->tmpl->addVar("_widget", "eyecatch_image", $eyecatchImageTag);		// アイキャッチ画像
 		
@@ -1085,11 +1120,11 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 		$this->db->getUnitType($defaultLang, array($this, 'unitTypeLoop'));
 
 		// 通貨タイプ選択メニュー作成
-		if ($this->gEnv->getMultiLanguage()){	// 多言語対応のとき
+/*		if ($this->gEnv->getMultiLanguage()){	// 多言語対応のとき
 			$this->db->getCurrency($defaultLang, array($this, 'currencyLoop'));
-		}
+		}*/
 		// 課税タイプ選択メニューの作成
-		$this->db->getTaxType($defaultLang, array($this, 'taxTypeLoop'));
+		$this->db->getTaxType(array($this, 'taxTypeLoop'));
 
 		// 商品画像プレビューの作成
 		// 画像小
@@ -1158,14 +1193,14 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 			$langId = $row['pt_language_id'];
 			
 			// 価格を取得
-			$priceArray = $this->getPrice($row2, self::STANDARD_PRICE);
+			$priceArray = $this->getPrice($row2, self::REGULAR_PRICE, $this->defaultCurrencyId);
 			$price = $priceArray['pp_price'];	// 価格
 			$currency = $priceArray['pp_currency_id'];	// 通貨
 			$taxType = $row['pt_tax_type_id'];					// 税種別			
 
 			// 価格作成
 			$this->ecObj->setCurrencyType($currency, $langId);		// 通貨設定
-			$this->ecObj->setTaxType($taxType, $langId);		// 税種別設定
+			$this->ecObj->setTaxType($taxType);		// 税種別設定
 			$totalPrice = $this->ecObj->getPriceWithTax($price, $dispPrice);	// 税込み価格取得
 			if (empty($taxType)) $dispPrice = '(未)';		// 税種別未選択のとき
 			
@@ -1278,12 +1313,13 @@ class admin_ec_mainProductWidgetContainer extends admin_ec_mainBaseWidgetContain
 	 *
 	 * @param array  	$srcRows			価格リスト
 	 * @param string	$priceType			価格のタイプ
+	 * @param string    $currencyId			通貨ID
 	 * @return array						取得した価格行
 	 */
-	function getPrice($srcRows, $priceType)
+	function getPrice($srcRows, $priceType, $currencyId)
 	{
 		for ($i = 0; $i < count($srcRows); $i++){
-			if ($srcRows[$i]['pp_price_type_id'] == $priceType){
+			if ($srcRows[$i]['pp_currency_id'] == $currencyId && $srcRows[$i]['pp_price_type_id'] == $priceType){
 				return $srcRows[$i];
 			}
 		}
