@@ -8,14 +8,14 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_flashWidgetContainer.php 1425 2009-01-07 04:49:14Z fishbone $
+ * @version    SVN: $Id: admin_flashWidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
 
-class admin_flashWidgetContainer extends BaseWidgetContainer
+class admin_flashWidgetContainer extends BaseAdminWidgetContainer
 {
 	private $sysDb;	// DB接続オブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
@@ -255,15 +255,13 @@ class admin_flashWidgetContainer extends BaseWidgetContainer
 		if (!empty($this->configId)) $this->tmpl->addVar("_widget", "id", $this->configId);		// 定義ID
 		$this->tmpl->addVar("_widget", "width",	$width);
 		$this->tmpl->addVar("_widget", "height",	$height);
-		$this->tmpl->addVar("_widget", "flash_url",	$url);
-		$this->tmpl->addVar("_widget", "preview_url",	$previewUrl);
+		$this->tmpl->addVar("_widget", "flash_url",	$this->getUrl($url));
+		$this->tmpl->addVar("_widget", "preview_url",	$this->getUrl($previewUrl));
 		$checked = '';
 		if ($showTitle) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "show_title", $checked);	// タイトルを表示するかどうか
 				
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);// 選択中のシリアル番号、IDを設定
-		$this->tmpl->addVar("_widget", "widget_url", $this->gEnv->getCurrentWidgetRootUrl());	// ウィジェットのルートディレクトリ
-		$this->tmpl->addVar("_widget", "root_url", $this->gEnv->getRootUrl());
 		
 		// 画面定義用の情報を戻す
 		$this->tmpl->addVar("_widget", "def_serial", $defSerial);	// ページ定義のレコードシリアル番号
@@ -383,7 +381,6 @@ class admin_flashWidgetContainer extends BaseWidgetContainer
 		$this->createItemList();
 		
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
-		$this->tmpl->addVar('_widget', 'admin_url', $this->gEnv->getDefaultAdminUrl());// 管理者URL
 		
 		// 画面定義用の情報を戻す
 		$this->tmpl->addVar("_widget", "def_serial", $defSerial);	// ページ定義のレコードシリアル番号
@@ -419,7 +416,7 @@ class admin_flashWidgetContainer extends BaseWidgetContainer
 				'ope_disabled' => $operationDisagled,			// 選択可能かどうか
 				'name' => $this->convertToDispString($name),		// 名前
 				'filename' => $filename,		// ファイル名
-				'url' => $url,					// URL
+				'url' => $this->getUrl($url),					// URL
 				'width' => $targetObj->width,					// Flashファイル幅
 				'height' => $targetObj->height,					// Flashファイル高さ
 				'def_count' => $defCount							// 使用数
